import functools

from anillo.http.responses import Response

from raven import Client


def wrap_sentry(func=None, *, url):
    """
    A middleware that capture exceptions and send it to the
    sentry server.

    This middleware requires a `url` keyword
    only parameter for provide the sentry url.

    :param url: Sentry url.
    :type url: dictionary
    """

    if func is None:
        return functools.partial(wrap_sentry, url=url)

    def wrapper(request):
        if url is None:
            return func(request)

        try:
            return func(request)
        except Exception as e:
            client = Client(url)
            client.captureException(extra={"request": request})
            raise e

    return wrapper



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup

setup(
    name='anillo_sentry',
    version=":versiontools:anillo_sentry:",
    description="Sentry integration middleware for anillo",
    long_description="",
    keywords='sentry, anillo',
    author='Jesús Espino García',
    author_email='jespinog@gmail.com',
    url='https://github.com/jespino/anillo_sentry',
    license='BSD',
    packages=['anillo_sentry', 'anillo_sentry'],
    install_requires=[
        'raven',
    ],
    setup_requires=[
        'versiontools >= 1.9.1',
    ],
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP',
    ]
)
